@@ -191,29 +191,29 @@ class EventbridgeToKinesisStreams(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventsRole")
     def events_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "eventsRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -253,9 +253,9 @@ class EventbridgeToKinesisStreamsProps:
         :summary: The properties for the EventbridgeToKinesisStreams Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = RuleProps(**event_rule_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+            event_bus_props = EventBusProps(**event_bus_props)
         if __debug__:
             type_hints = typing.get_type_hints(EventbridgeToKinesisStreamsProps.__init__)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
